@@ -70,7 +70,7 @@ def make_omnetpp_project_description(version, base_version=None, is_modernized=F
     # Qtenv was added in omnetpp-5.0 (and coexisted with Tkenv throughout the 5.x series).
     # Note that omnetpp-5.0 searches for Qt4 by default, but also accepts Qt5.
     qt_packages = [] if version < "5.0" else  ["qt5.qtbase", "qt5.qtsvg", "qt5.qtwayland" if is_linux else None] if version < "6.2" \
-                  else ["qt6ct", "adwaita-qt6", "kdePackages.breeze", "qt6.qtbase", "qt6.qtsvg", "qt6.qtwayland" if is_linux else None]
+                  else (["qt6.qtbase", "qt6.qtsvg"] + (["qt6.qtwayland", "qt6ct", "adwaita-qt6", "kdePackages.breeze"] if is_linux else []))
 
     # The default Tcl/Tk version in Nix is 8.6, and that's OK with most of our releases.
     # However, early 4.x versions don't compile with Tcl 8.6 because no longer supports "interp->result" in the C API, so they need version 8.5.
@@ -86,7 +86,9 @@ def make_omnetpp_project_description(version, base_version=None, is_modernized=F
     # Later versions (especially >= 4.4) have introduced backward-incompatible changes with pattern rules that are incompatible
     # with older OMNeT++ releases. These issues can even cause mysterious compiler crashes on subsequent builds because of
     # concurrency issues between the message compiler and the compiler.
-    other_packages = ["llvmPackages.bintools", "bison", "flex", "perl", "libxml2", "expat", "which", "xdg-utils", "pkg-config", "ccache", "gnumake42", ("gdb" if not is_macos else None), "vim", ("python3" if version > "5.0" else None)]
+    other_packages = ["llvmPackages.bintools", "bison", "flex", "perl", "libxml2", "expat", "which", "xdg-utils", "pkg-config", "ccache", "gnumake42", "vim"]
+    other_packages += ["python3"] if version > "5.0" else []
+    other_packages += ["lldb"] if version >= "6.2" else ["gdb"] if not is_macos else []
 
     # Python packages required for the Analysis Tool and the omnetpp.scave package. Version 6.0 and up.
     # note: "python3Packages.pyqt*" are needed by matplotlib in opp_charttool
@@ -144,6 +146,12 @@ def make_omnetpp_project_description(version, base_version=None, is_modernized=F
         sed -i -e 's|export PIP_PREFIX|#export PIP_PREFIX|' -e 's|export PYTHONNOUSERSITE|#export PYTHONNOUSERSITE|' setenv
         """ if version < "6.1" and is_macos and is_x86_64 else None,
 
+        # turn off brew detection as it interferes with the Nix environment
+        "sed -i -e 's|command -v brew|command -v brew_off|' setenv" if version.startswith("6.1") else None,
+
+        # the 6.2.0 version missed this line preventing the build on macOS with Qt6
+        r"""sed -i -e 's|-F $QT_INSTALL_LIBS"|-F $QT_INSTALL_LIBS"\n            QT_CFLAGS="-F $QT_INSTALL_LIBS -mmacosx-version-min=12.0"|' configure configure.in""" if version == "6.2.0" else None, # this specific version missed this line preventing the build on macOS with Qt6
+
         "sed -i 's|exit 1|# exit 1|' setenv" if not is_modernized and version.startswith("4.") else None, # otherwise setenv complains and exits
         "sed -i 's|echo \"Error: not a login shell|# echo \"Error: not a login shell|' setenv" if not is_modernized and version.startswith("4.") else None, # otherwise setenv complains and exits
 
@@ -205,7 +213,7 @@ def make_omnetpp_project_description(version, base_version=None, is_modernized=F
         "sed -i 's|^WITH_OSG=yes|WITH_OSG=no|' configure.user",  # we currently don't support OSG and osgEarth in opp_env
         "sed -i 's|^WITH_OSGEARTH=yes|WITH_OSGEARTH=no|' configure.user",
         "sed -i 's|^WITH_PARSIM=no|WITH_PARSIM=yes|' configure.user" if version >= "6.0" else None, # NOTE: we need WITH_PARSIM (but not MPI) for the "d" fingerprint ingredient to work
-        """sed -i 's|#MPI_LIBS="-lmpi++ -lmpi"   #SGI|#MPI_LIBS="-lmpi++ -lmpi"   #SGI\\nMPI_LIBS="-ldisabled"|' src/sim/cfingerprint.cc""" if version.startswith("5.0") else None,
+        """sed -i 's|#MPI_LIBS="-lmpi++ -lmpi"   #SGI|#MPI_LIBS="-lmpi++ -lmpi"   #SGI\\nMPI_LIBS="-ldisabled"|' configure.user""" if version >= "5.0" else None,
         """sed -i 's|#include "parsim/cmemcommbuffer.h"|#ifdef WITH_PARSIM\\n#include "parsim/cmemcommbuffer.h"\\n#endif|' src/sim/cfingerprint.cc""" if version.startswith("5.0") else None,
         """sed -i 's|cMemCommBuffer buffer;|#ifdef WITH_PARSIM\\ncMemCommBuffer buffer;|' src/sim/cfingerprint.cc""" if version.startswith("5.0") else None,
         """sed -i 's|delete copy;|delete copy;\\n#else\\nthrow cRuntimeError("Fingerprint is configured to contain MESSAGE_DATA (d),"\\n" but parallel simulation support is disabled (WITH_PARSIM=no)"\\n" which is required for serialization.");\\n#endif|' src/sim/cfingerprint.cc""" if version.startswith("5.0") else None,
